# **Welcome to Optumi 👋**

### Description

Optumi is a cloud service that makes it easy for data scientists to develop & train ML models on powerful computing resources.

We offer a JupyterLab extension that runs local Python notebooks in the cloud. We offer access to a wide variety of powerful cloud resources to launch interactive sessions or batch jobs.